Description Author(s) See Also
hyderogen provides a toolset for quickly building Jekyll projects from your package's roxygen. These tools focus on creating detailed front matter and plain templates. You can then further customize these templates. When you update your roxygen you can rebuild your Jekyll front matter, while leaving the templates untouched.
This package is a work in progress. If you try it out please do not be shy about reporting bugs or less-than-ideal results. All feedback is welcome at nteetor/hyderogen/issues.
Maintainer: Nathan Teetor nathanteetor@gmail.com
For more on Jekyll check out https://jekyllrb.com/docs/home/.
For more on using Jekyll and Github pages check out, https://jekyllrb.com/docs/github-pages/.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.